--
-- ORTHOINSPECTOR MySQL database schema
--

SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Base de données: `orthoinspector_test`
--

-- --------------------------------------------------------

--
-- Structure de la table `version`
--

CREATE TABLE IF NOT EXISTS `version` (
  `pk_version` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `date` date NOT NULL,
  `type` int(11) NOT NULL,
  `description` text NOT NULL,
  PRIMARY KEY (`pk_version`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COMMENT='handle database version informations' ;

--
-- Structure de la table `sequences`
--

CREATE TABLE IF NOT EXISTS `sequences` (
  `pk_sequence` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `checksum` varchar(64) NOT NULL,
  `description` text NOT NULL,
  `sequence` text NOT NULL,
  `identifier` varchar(255) NOT NULL,
  `pk_version` int(10) unsigned NOT NULL,
  PRIMARY KEY (`pk_sequence`),
  KEY idx_sequences_identifier (identifier)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 PACK_KEYS=1 ROW_FORMAT=COMPRESSED COMMENT='contains sequences ids, description, sequence itself' ;


--
-- Structure de la table `bank`
--

CREATE TABLE IF NOT EXISTS `bank` (
  `pk_bank` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `identifier` text NOT NULL,
  `description` text,
  PRIMARY KEY (`pk_bank`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COMMENT='bank source of sequence and organisms';


--
-- Structure de la table `best_hit`
--

CREATE TABLE IF NOT EXISTS `best_hit` (
  `pk_bh` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `pk_sequencea` int(10) unsigned NOT NULL,
  `pk_sequenceb` int(10) unsigned NOT NULL,
  `pk_organisma` int(10) unsigned NOT NULL,
  `pk_organismb` int(10) unsigned NOT NULL,
  `pk_version` int(10) unsigned NOT NULL,
  PRIMARY KEY (`pk_bh`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 ;


--
-- Structure de la table `blast`
--

CREATE TABLE IF NOT EXISTS `blast` (
  `pk_blast` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `pk_sequence` int(10) unsigned NOT NULL,
  `pk_version` int(10) unsigned NOT NULL,
  PRIMARY KEY (`pk_blast`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 ;


--
-- Structure de la table `hit`
--

CREATE TABLE IF NOT EXISTS `hit` (
  `pk_blast` int(10) unsigned NOT NULL,
  `pk_sequence` int(10) unsigned NOT NULL,
  `pk_version` int(10) unsigned NOT NULL,
  `percent_id` double NOT NULL,
  `align_length` int(11) NOT NULL,
  `mismatches` int(11) NOT NULL,
  `gap_open` int(11) NOT NULL,
  `q_start` int(11) NOT NULL,
  `q_end` int(11) NOT NULL,
  `s_start` int(11) NOT NULL,
  `s_end` int(11) NOT NULL,
  `evalue` double NOT NULL,
  `bitscore` double NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


--
-- Structure de la table `inparalog`
--

CREATE TABLE IF NOT EXISTS `inparalog` (
  `pk_inparalog` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `pk_organism` int(10) unsigned NOT NULL,
  `pk_organism_rapporteur` int(10) unsigned NOT NULL,
  `pk_version` int(10) unsigned NOT NULL,
  PRIMARY KEY (`pk_inparalog`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COMMENT='contains validated inparalogs' ;


--
-- Structure de la table `ln_inparalog_sequence`
--

CREATE TABLE IF NOT EXISTS `ln_inparalog_sequence` (
  `pk_sequence` int(10) unsigned NOT NULL,
  `pk_inparalog` bigint(20) unsigned NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


--
-- Structure de la table `ln_organism_bank`
--

CREATE TABLE IF NOT EXISTS `ln_organism_bank` (
  `pk_organism` int(10) unsigned NOT NULL,
  `pk_bank` int(10) unsigned NOT NULL,
  `taxid` int(11) NOT NULL,
  `date` date NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COMMENT='link between organism and bank sources';


--
-- Structure de la table `ln_organism_sequence`
--

CREATE TABLE IF NOT EXISTS `ln_organism_sequence` (
  `pk_sequence` int(10) unsigned NOT NULL,
  `pk_organism` int(10) unsigned NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COMMENT='link between sequence and organism';


--
-- Structure de la table `ln_putative_inparalog_sequence`
--

CREATE TABLE IF NOT EXISTS `ln_putative_inparalog_sequence` (
  `pk_sequence` int(10) unsigned NOT NULL,
  `pk_putative_inparalog` bigint(20) unsigned NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


--
-- Structure de la table `manytomany`
--

CREATE TABLE IF NOT EXISTS `manytomany` (
  `pk_manytomany` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `pk_inparaloga` bigint(20) unsigned NOT NULL,
  `pk_inparalogb` bigint(20) unsigned NOT NULL,
  `pk_organisma` int(10) unsigned NOT NULL,
  `pk_organismb` int(10) unsigned NOT NULL,
  PRIMARY KEY (`pk_manytomany`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 ;


--
-- Structure de la table `no_hit`
--

CREATE TABLE IF NOT EXISTS `no_hit` (
  `pk_sequence` int(10) unsigned NOT NULL,
  `pk_version` int(10) unsigned NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


--
-- Structure de la table `no_hit_to_orga`
--

CREATE TABLE IF NOT EXISTS `no_hit_to_orga` (
  `pk_sequence` int(10) unsigned NOT NULL,
  `pk_organism` int(10) unsigned NOT NULL,
  `pk_version` int(10) unsigned NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


--
-- Structure de la table `onetomany`
--

CREATE TABLE IF NOT EXISTS `onetomany` (
  `pk_onetomany` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `pk_sequencea` int(10) unsigned NOT NULL,
  `pk_inparalogb` bigint(20)) unsigned NOT NULL,
  `pk_organisma` int(10) unsigned NOT NULL,
  `pk_organismb` int(10) unsigned NOT NULL,
  PRIMARY KEY (`pk_onetomany`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 ;


--
-- Structure de la table `onetoone`
--

CREATE TABLE IF NOT EXISTS `onetoone` (
  `pk_onetoone` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `pk_sequencea` int(10) unsigned NOT NULL,
  `pk_sequenceb` int(10) unsigned NOT NULL,
  `pk_organisma` int(10) unsigned NOT NULL,
  `pk_organismb` int(10) unsigned NOT NULL,
  PRIMARY KEY (`pk_onetoone`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 ;


--
-- Structure de la table `organism`
--

CREATE TABLE IF NOT EXISTS `organism` (
  `pk_organism` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `identifier` varchar(255) NOT NULL,
  `genus` varchar(255) NOT NULL,
  `species` varchar(255) NOT NULL,
  `phylum` text NOT NULL,
  PRIMARY KEY (`pk_organism`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COMMENT='contains organism identifiers, names, taxid ...' ;


--
-- Structure de la table `putative_inparalog`
--

CREATE TABLE IF NOT EXISTS `putative_inparalog` (
  `pk_putative_inparalog` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `pk_sequence` int(10) unsigned NOT NULL,
  `pk_organism` int(10) unsigned NOT NULL,
  `pk_organism_rapporteur` int(10) unsigned NOT NULL,
  `pk_version` int(10) unsigned NOT NULL,
  PRIMARY KEY (`pk_putative_inparalog`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 ;

--only these index to get pk_sequences keys to create ln_sequence_organism



--
-- Constraints generated at launch (database intallation)
--


ALTER TABLE `ln_organism_bank`
  ADD CONSTRAINT `ln_orgabank_pk_bank_fk_constraint` FOREIGN KEY (`pk_bank`) REFERENCES `bank` (`pk_bank`),
  ADD CONSTRAINT `ln_orgabank_pk_organism_fk_constraint` FOREIGN KEY (`pk_organism`) REFERENCES `organism` (`pk_organism`);

ALTER TABLE `ln_organism_sequence`
  ADD CONSTRAINT `ln_organism_sequence_pk_organism_fk_constraint` FOREIGN KEY (`pk_organism`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `ln_organism_sequence_pk_sequence_fk_constraint` FOREIGN KEY (`pk_sequence`) REFERENCES `sequences` (`pk_sequence`);

ALTER TABLE `sequences`
  ADD CONSTRAINT `sequences_pk_version_fk_constraint` FOREIGN KEY (`pk_version`) REFERENCES `version` (`pk_version`);


--
-- Contraints for "blast parsing" step
--
ALTER TABLE `ln_putative_inparalog_sequence`
  ADD CONSTRAINT `ln_putinparaseq_pk_putative_inparalog_fk_constraint` FOREIGN KEY (`pk_putative_inparalog`) REFERENCES `putative_inparalog` (`pk_putative_inparalog`),
  ADD CONSTRAINT `ln_putinparaseq_pk_sequence_fk_constraint` FOREIGN KEY (`pk_sequence`) REFERENCES `sequences` (`pk_sequence`);

ALTER TABLE `putative_inparalog`
  ADD CONSTRAINT `putative_inparalog_pk_organism_fk_constraint` FOREIGN KEY (`pk_organism`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `putative_inparalog_pk_organism_rapporteur_fk_constraint` FOREIGN KEY (`pk_organism_rapporteur`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `putative_inparalog_pk_sequence_fk_constraint` FOREIGN KEY (`pk_sequence`) REFERENCES `sequences` (`pk_sequence`),
  ADD CONSTRAINT `putative_inparalog_pk_version_fk_constraint` FOREIGN KEY (`pk_version`) REFERENCES `version` (`pk_version`);
ALTER TABLE `best_hit`
  ADD CONSTRAINT `bh_orgaa_fk_constraint` FOREIGN KEY (`pk_organisma`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `bh_orgab_fk_constraint` FOREIGN KEY (`pk_organismb`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `bh_seqa_fk_constraint` FOREIGN KEY (`pk_sequencea`) REFERENCES `sequences` (`pk_sequence`),
  ADD CONSTRAINT `bh_seqb_fk_constraint` FOREIGN KEY (`pk_sequenceb`) REFERENCES `sequences` (`pk_sequence`),
  ADD CONSTRAINT `bh_version_fk_constraint` FOREIGN KEY (`pk_version`) REFERENCES `version` (`pk_version`);





--
-- Contraints for "blast parsing" step, used if the option "create blast tables" option is selected
-- These tables are used only for the "best-hit density graph" tool of the graphical interface
--

ALTER TABLE `blast`
  ADD CONSTRAINT `blast_pk_sequence_fk_constraint` FOREIGN KEY (`pk_sequence`) REFERENCES `sequences` (`pk_sequence`),
  ADD CONSTRAINT `blast_pk_version_fk_constraint` FOREIGN KEY (`pk_version`) REFERENCES `version` (`pk_version`);

ALTER TABLE `hit`
  ADD CONSTRAINT `hit_pk_blast_fk_constraint` FOREIGN KEY (`pk_blast`) REFERENCES `blast` (`pk_blast`),
  ADD CONSTRAINT `hit_pk_sequence_fk_constraint` FOREIGN KEY (`pk_sequence`) REFERENCES `sequences` (`pk_sequence`),
  ADD CONSTRAINT `hit_pk_version_fk_constraint` FOREIGN KEY (`pk_version`) REFERENCES `version` (`pk_version`);


--
-- Contraints for "blast parsing" step, used if the option "create no_hit/no_hit_to_orga tables" option is selected
-- These tables are used only for the "extended statistics" tool of the graphical interface
--
ALTER TABLE `no_hit`
  ADD CONSTRAINT `no_hit_pk_sequence_fk_constraint` FOREIGN KEY (`pk_sequence`) REFERENCES `sequences` (`pk_sequence`),
  ADD CONSTRAINT `no_hit_pk_version_fk_constraint` FOREIGN KEY (`pk_version`) REFERENCES `version` (`pk_version`);

ALTER TABLE `no_hit_to_orga`
  ADD CONSTRAINT `nhto_pk_organism_fk_constraint` FOREIGN KEY (`pk_organism`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `nhto_pk_sequence_fk_constraint` FOREIGN KEY (`pk_sequence`) REFERENCES `sequences` (`pk_sequence`),
  ADD CONSTRAINT `nhto_pk_version_fk_constraint` FOREIGN KEY (`pk_version`) REFERENCES `version` (`pk_version`);

--
-- Constraints for the "inparalogy_validation" step
--
ALTER TABLE `inparalog`
  ADD CONSTRAINT `inparalog_pk_organism_fk_constraint` FOREIGN KEY (`pk_organism`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `inparalog_pk_organism_rapporteur_fk_constraint` FOREIGN KEY (`pk_organism_rapporteur`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `inparalog_pk_version_fk_constraint` FOREIGN KEY (`pk_version`) REFERENCES `version` (`pk_version`);

ALTER TABLE `ln_inparalog_sequence`
  ADD CONSTRAINT `ln_inparaseq_pk_inparalog_fk_constraint` FOREIGN KEY (`pk_inparalog`) REFERENCES `inparalog` (`pk_inparalog`),
  ADD CONSTRAINT `ln_inparaseq_pk_sequence_fk_constraint` FOREIGN KEY (`pk_sequence`) REFERENCES `sequences` (`pk_sequence`);

--
-- Constraints for the "orthology calculation" step
--
ALTER TABLE `onetomany`
  ADD CONSTRAINT `otm_inparab_fk_constraint` FOREIGN KEY (`pk_inparalogb`) REFERENCES `inparalog` (`pk_inparalog`),
  ADD CONSTRAINT `otm_orgaa_fk_constraint` FOREIGN KEY (`pk_organisma`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `otm_orgab_fk_constraint` FOREIGN KEY (`pk_organismb`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `otm_seqa_fk_constraint` FOREIGN KEY (`pk_sequencea`) REFERENCES `sequences` (`pk_sequence`);

ALTER TABLE `onetoone`
  ADD CONSTRAINT `oto_orgaa_fk_constraint` FOREIGN KEY (`pk_organisma`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `oto_orgab_fk_constraint` FOREIGN KEY (`pk_organismb`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `oto_seqa_fk_constraint` FOREIGN KEY (`pk_sequencea`) REFERENCES `sequences` (`pk_sequence`),
  ADD CONSTRAINT `oto_seqb_fk_constraint` FOREIGN KEY (`pk_sequenceb`) REFERENCES `sequences` (`pk_sequence`);

ALTER TABLE `manytomany`
  ADD CONSTRAINT `mtm_inparaa_fk_constraint` FOREIGN KEY (`pk_inparaloga`) REFERENCES `inparalog` (`pk_inparalog`),
  ADD CONSTRAINT `mtm_inparab_fk_constraint` FOREIGN KEY (`pk_inparalogb`) REFERENCES `inparalog` (`pk_inparalog`),
  ADD CONSTRAINT `mtm_orgaa_fk_constraint` FOREIGN KEY (`pk_organisma`) REFERENCES `organism` (`pk_organism`),
  ADD CONSTRAINT `mtm_orgab_fk_constraint` FOREIGN KEY (`pk_organismb`) REFERENCES `organism` (`pk_organism`);









